@@ -1,7 +1,7 @@
 /* snac - A simple, minimalistic ActivityPub instance */
 /* copyright (c) 2022 - 2025 grunfink et al. / MIT license */
 
-#define VERSION "2.82"
+#define VERSION "2.84"
 
 #define USER_AGENT "snac/" VERSION
 
@@ -44,7 +44,7 @@ extern int dbglevel;
 
 int mkdirx(const char *pathname);
 
-int valid_status(int status);
+#define valid_status(status) xs_http_valid_status(status)
 xs_str *tid(int offset);
 double ftime(void);
 
@@ -78,6 +78,13 @@ typedef struct {
 
 extern srv_state *p_state;
 
+enum {
+    SCOPE_PUBLIC = 0,
+    SCOPE_MENTIONED = 1,
+    SCOPE_UNLISTED = 2,
+    SCOPE_FOLLOWERS = 3,
+};
+
 void snac_log(snac *user, xs_str *str);
 #define snac_debug(user, level, str) do { if (dbglevel >= (level)) \
     { snac_log((user), (str)); } } while (0)
@@ -233,7 +240,7 @@ xs_list *tag_search(const char *tag, int skip, int show);
 xs_val *list_maint(snac *user, const char *list, int op);
 xs_str *list_timeline_fn(snac *user, const char *list);
 xs_list *list_timeline(snac *user, const char *list, int skip, int show);
-xs_val *list_content(snac *user, const char *list_id, const char *actor_md5, int op);
+xs_val *list_members(snac *user, const char *list_id, const char *actor_md5, int op);
 void list_distribute(snac *user, const char *who, const xs_dict *post);
 
 int actor_add(const char *actor, const xs_dict *msg);
@@ -278,6 +285,11 @@ int content_match(const char *file, const xs_dict *msg);
 xs_list *content_search(snac *user, const char *regex,
             int priv, int skip, int show, int max_secs, int *timeout);
 
+int actor_failure(const char *actor, int op);
+int instance_failure(const char *url, int op);
+
+int grave(const char *objid, int op);
+
 void enqueue_input(snac *snac, const xs_dict *msg, const xs_dict *req, int retries);
 void enqueue_shared_input(const xs_dict *msg, const xs_dict *req, int retries);
 void enqueue_output_raw(const char *keyid, const char *seckey,
@@ -298,6 +310,8 @@ void enqueue_actor_refresh(snac *user, const char *actor, int forward_secs);
 void enqueue_webmention(const xs_dict *msg);
 void enqueue_notify_webhook(snac *user, const xs_dict *noti, int retries);
 void enqueue_collect_replies(snac *user, const char *post);
+void enqueue_collect_outbox(snac *user, const char *actor_id);
+void enqueue_fsck(void);
 
 int was_question_voted(snac *user, const char *id);
 
@@ -336,6 +350,7 @@ const char *default_avatar_base64(void);
 xs_str *process_tags(snac *snac, const char *content, xs_list **tag);
 
 void collect_replies(snac *user, const char *id);
+void collect_outbox(snac *user, const char *actor_id);
 
 const char *get_atto(const xs_dict *msg);
 const char *get_in_reply_to(const xs_dict *msg);
@@ -361,6 +376,7 @@ xs_dict *msg_accept(snac *snac, const xs_val *object, const char *to);
 xs_dict *msg_question(snac *user, const char *content, xs_list *attach,
                       const xs_list *opts, int multiple, int end_secs);
 xs_dict *msg_replies(snac *user, const char *id, int fill);
+int get_msg_visibility(const xs_dict *msg);
 
 int activitypub_request(snac *snac, const char *url, xs_dict **data);
 int actor_request(snac *user, const char *actor, xs_dict **data);
@@ -450,14 +466,6 @@ void import_list_csv(snac *user, const char *fn);
 void import_csv(snac *user);
 int parse_port(const char *url, const char **errstr);
 
-typedef enum {
-#define HTTP_STATUS(code, name, text) HTTP_STATUS_ ## name = code,
-#include "http_codes.h"
-#undef HTTP_STATUS
-} http_status;
-
-const char *http_status_text(int status);
-
 typedef struct {
     double timestamp;
     char   *text;
@@ -475,3 +483,5 @@ xs_str *rss_from_timeline(snac *user, const xs_list *timeline,
                         const char *title, const char *link, const char *desc);
 void rss_to_timeline(snac *user, const char *url);
 void rss_poll_hashtags(void);
+
+void data_fsck(void);
